==> coil-0.11.0-javadoc.jar: coil-base/coil.util/-logger/index.md <==
[coil-base](../../index.md) / [coil.util](../index.md) / [Logger](./index.md)

# Logger

`interface Logger`

Logging interface for [ImageLoader](../../coil/-image-loader/index.md)s.

**See Also**

[ImageLoaderBuilder.logger](../../coil/-image-loader-builder/logger.md)

[DebugLogger](../-debug-logger/index.md)

### Properties

| Name | Summary |
|---|---|
| [level](level.md) | The minimum level for this logger to log.`abstract var level: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

### Functions

| Name | Summary |
|---|---|
| [log](log.md) | Write [message](log.md#coil.util.Logger$log(kotlin.String, kotlin.Int, kotlin.String, kotlin.Throwable)/message) and/or [throwable](log.md#coil.util.Logger$log(kotlin.String, kotlin.Int, kotlin.String, kotlin.Throwable)/throwable) to a logging destination.`abstract fun log(tag: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, priority: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`, message: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, throwable: `[`Throwable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)`?): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inheritors

| Name | Summary |
|---|---|
| [DebugLogger](../-debug-logger/index.md) | A [Logger](./index.md) implementation that writes to Android's [Log](https://developer.android.com/reference/android/util/Log.html).`class DebugLogger : `[`Logger`](./index.md) |

==> coil-1.0.0-rc3-javadoc.jar: coil-base/coil.util/-logger/index.md <==
[coil-base](../../index.md) / [coil.util](../index.md) / [Logger](./index.md)

# Logger

`interface Logger`

Logging interface for [ImageLoader](../../coil/-image-loader/index.md)s.

**See Also**

[ImageLoader.Builder.logger](../../coil/-image-loader/-builder/logger.md)

[DebugLogger](../-debug-logger/index.md)

### Properties

| Name | Summary |
|---|---|
| [level](level.md) | The minimum level for this logger to log.`abstract var level: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

### Functions

| Name | Summary |
|---|---|
| [log](log.md) | Write [message](log.md#coil.util.Logger$log(kotlin.String, kotlin.Int, kotlin.String, kotlin.Throwable)/message) and/or [throwable](log.md#coil.util.Logger$log(kotlin.String, kotlin.Int, kotlin.String, kotlin.Throwable)/throwable) to a logging destination.`abstract fun log(tag: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, priority: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`, message: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, throwable: `[`Throwable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)`?): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inheritors

| Name | Summary |
|---|---|
| [DebugLogger](../-debug-logger/index.md) | A [Logger](./index.md) implementation that writes to Android's [Log](https://developer.android.com/reference/android/util/Log.html).`class DebugLogger : `[`Logger`](./index.md) |
